@@ -1,13 +1,13 @@
 __author__ = "Vanessa Sochat"
-__copyright__ = "Copyright 2021-2022, Vanessa Sochat"
+__copyright__ = "Copyright 2021, Vanessa Sochat"
 __license__ = "MPL 2.0"
 
-__version__ = "0.0.4"
+__version__ = "0.0.11"
 AUTHOR = "Vanessa Sochat"
 NAME = "singularity-hpc"
 PACKAGE_URL = "https://github.com/singularityhub/singularity-hpc"
 KEYWORDS = "singularity, containers, hpc, lmd"
-DESCRIPTION = "Local registry intended for HPC using containers and system modules."
+DESCRIPTION = "Local filesystem database for Singularity containers with LMOD"
 LICENSE = "LICENSE"
 
 ################################################################################
@@ -16,15 +16,20 @@ LICENSE = "LICENSE"
 # Since we assume wanting Singularity and lmod, we require spython and Jinja2
 
 INSTALL_REQUIRES = (
-    # 0.1.18 added support for oras
-    ("spython", {"min_version": "0.1.18"}),
+    ("spython", {"min_version": "0.1.13"}),
     ("Jinja2", {"min_version": None}),
     ("jsonschema", {"min_version": None}),
     ("ruamel.yaml", {"min_version": None}),
+    ("sqlalchemy", {"min_version": None}),
 )
 
 TESTS_REQUIRES = (("pytest", {"min_version": "4.6.2"}),)
 
+################################################################################
+# Install basic without database (default)
+
+INSTALL_BASIC = INSTALL_REQUIRES[:-1]
+
 ################################################################################
 # Submodule Requirements (versions that include database)
 
